from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:AVERage \n
		Snippet: value: List[float] = driver.fftSpecAn.power.average.fetch() \n
		Returns the FFT spectrum analyzer traces across the selected frequency span (see method RsCmwGprfMeas.Configure.FftSpecAn.
		fspan) . The results of the current, average, minimum and maximum traces can be retrieved. \n
		Use RsCmwGprfMeas.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Frequency-dependent power values. Each of the traces contains 801 values, irrespective of the frequency span. Range: -100.0 dBm to 57.0 dBm, Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:AVERage?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:AVERage \n
		Snippet: value: List[float] = driver.fftSpecAn.power.average.read() \n
		Returns the FFT spectrum analyzer traces across the selected frequency span (see method RsCmwGprfMeas.Configure.FftSpecAn.
		fspan) . The results of the current, average, minimum and maximum traces can be retrieved. \n
		Use RsCmwGprfMeas.reliability.last_value to read the updated reliability indicator. \n
			:return: power: Frequency-dependent power values. Each of the traces contains 801 values, irrespective of the frequency span. Range: -100.0 dBm to 57.0 dBm, Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:FFTSanalyzer:POWer:AVERage?', suppressed)
		return response
