from ..Internal.Core import Core
from ..Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nrpm:
	"""Nrpm commands group definition. 8 total commands, 2 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nrpm", core, parent)

	@property
	def state(self):
		"""state commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_state'):
			from .Nrpm_.State import State
			self._state = State(self._core, self._base)
		return self._state

	@property
	def sensor(self):
		"""sensor commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sensor'):
			from .Nrpm_.Sensor import Sensor
			self._sensor = Sensor(self._core, self._base)
		return self._sensor

	def initiate(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.initiate() \n
		No command help available \n
		"""
		self._core.io.write(f'INITiate:GPRF:MEASurement<Instance>:NRPM')

	def initiate_with_opc(self) -> None:
		"""SCPI: INITiate:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.initiate_with_opc() \n
		No command help available \n
		Same as initiate, but waits for the operation to complete before continuing further. Use the RsCmwGprfMeas.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'INITiate:GPRF:MEASurement<Instance>:NRPM')

	def stop(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.stop() \n
		No command help available \n
		"""
		self._core.io.write(f'STOP:GPRF:MEASurement<Instance>:NRPM')

	def stop_with_opc(self) -> None:
		"""SCPI: STOP:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.stop_with_opc() \n
		No command help available \n
		Same as stop, but waits for the operation to complete before continuing further. Use the RsCmwGprfMeas.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'STOP:GPRF:MEASurement<Instance>:NRPM')

	def abort(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.abort() \n
		No command help available \n
		"""
		self._core.io.write(f'ABORt:GPRF:MEASurement<Instance>:NRPM')

	def abort_with_opc(self) -> None:
		"""SCPI: ABORt:GPRF:MEASurement<Instance>:NRPM \n
		Snippet: driver.nrpm.abort_with_opc() \n
		No command help available \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsCmwGprfMeas.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'ABORt:GPRF:MEASurement<Instance>:NRPM')

	def clone(self) -> 'Nrpm':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Nrpm(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group
