from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ....Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Average:
	"""Average commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("average", core, parent)

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:GPRF:MEASurement<Instance>:SPECtrum:AVERage:AVERage \n
		Snippet: value: List[float] = driver.spectrum.average.average.fetch() \n
		Returns the traces calculated with the average detector. Current, average, maximum and minimum traces can be retrieved.
		The averaging mode is defined via method RsCmwGprfMeas.Configure.Spectrum.amode. \n
		Use RsCmwGprfMeas.reliability.last_value to read the updated reliability indicator. \n
			:return: power: 1001 values Range: -150 dBm to 50 dBm, Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:GPRF:MEASurement<Instance>:SPECtrum:AVERage:AVERage?', suppressed)
		return response

	def read(self) -> List[float]:
		"""SCPI: READ:GPRF:MEASurement<Instance>:SPECtrum:AVERage:AVERage \n
		Snippet: value: List[float] = driver.spectrum.average.average.read() \n
		Returns the traces calculated with the average detector. Current, average, maximum and minimum traces can be retrieved.
		The averaging mode is defined via method RsCmwGprfMeas.Configure.Spectrum.amode. \n
		Use RsCmwGprfMeas.reliability.last_value to read the updated reliability indicator. \n
			:return: power: 1001 values Range: -150 dBm to 50 dBm, Unit: dBm"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:GPRF:MEASurement<Instance>:SPECtrum:AVERage:AVERage?', suppressed)
		return response
